/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2007-2008. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *******************************************************************************/
(function() {

dojo.provide("com.ibm.rational.report.web.core.app.internal.MessageFormatter");

dojo.require("dojox.data.dom");
dojo.require("com.ibm.rational.report.web.core.app.internal.common.Loading");
dojo.requireLocalization("com.ibm.rational.report.web.core.app.serviceability", "Messages");
dojo.requireLocalization("com.ibm.rational.report.web.core.app.internal", "Messages");

var ServiceabilityMessages	= dojo.i18n.getLocalization("com.ibm.rational.report.web.core.app.serviceability", "Messages");
var InternalMessages		= dojo.i18n.getLocalization("com.ibm.rational.report.web.core.app.internal", "Messages");
var DefaultIconsLocation	= dojo.moduleUrl("com.ibm.rational.report.web.core", "app/internal/images/");

/**
 * Displays messages that meet serviceability requirements.
 */
com.ibm.rational.report.web.core.app.internal.MessageFormatter = function(msgDiv) {
	
	this._msgDiv = msgDiv;
	this._loadingIcon = new com.ibm.rational.report.web.core.app.internal.common.Loading();
	
	this.formatErrorMessage = function(msg, error) {
		if (error) {
			if (error.status == 0) {
				msg = ServiceabilityMessages.SERVER_UNREACHABLE;
			}
			else {
				var reason = error.message;
				if (reason.length > 8) {
					reason = reason.substring(8);
				}
				msg = msg + " " + ServiceabilityMessages.REASON_LABEL + " " + reason;
			}
		}
		return msg;
	};
	
	this.displayErrorMessage = function(msg, error) {
		this._displayMessage(this.formatErrorMessage(msg, error), "errorMsg");
	};
	
	this.displaySuccessMessage = function(msg) {
		this._displayMessage(msg, "successMsg");
	};
	
	this.displayWarningMessage = function(msg) {
		this._displayMessage(msg, "warningMsg");
	};
	
	this.displayLoadingMessage = function(msg) {
		if (msg == null || msg == "undefined") {
			msg = InternalMessages.LOADING_PROGRESS_MSG;
		}	
		this._displayMessage(msg, "loadingMsg");
	};
	
	this.displayNoMessage = function() {
		dojox.data.dom.removeChildren(this._msgDiv);
		this._msgDiv.className = "noDisplay";
	};	
	
	// do not call this method directly.
	this._displayMessage = function(msg, msgType) {
		dojox.data.dom.removeChildren(this._msgDiv);
		var img = document.createElement("img");
		
		if (msgType == "warningMsg") {
			img.src = DefaultIconsLocation + "warning.gif";
			this._msgDiv.className= "warningMsg";
		} else if (msgType == "statusMsg") {
			img.src = DefaultIconsLocation + "progress.gif";
			this._msgDiv.className= "successMsg";
		} 
		else if (msgType == "loadingMsg") {
			this._msgDiv.className= "statusMsg";
			img.src = DefaultIconsLocation + "progress.gif";	
		}
		else if (msgType == "successMsg") {
			img.src = DefaultIconsLocation + "success.gif";
			this._msgDiv.className= "successMsg";			
		}
		else {
			img.src = DefaultIconsLocation + "error.gif";
			this._msgDiv.className= "errorMsg";	
		}
		if (dojo.isIE) {
			img.align = "bottom";
		} else if (dojo.isMozilla) {
			img.align = "top";
		}	
		
		this._msgDiv.appendChild(img);
		this._msgDiv.appendChild(document.createTextNode(msg));
	};		
	
};

})();
